==> basic-6.x-1.1.tar.gz: basic/node.tpl.php <==
<?php
// $Id: node.tpl.php,v 1.1.4.3 2008/07/07 18:20:50 stevek Exp $

/**
 * @file node.tpl.php
 *
 * Theme implementation to display a node.
 *
 * Available variables:
 * - $title: the (sanitized) title of the node.
 * - $content: Node body or teaser depending on $teaser flag.
 * - $picture: The authors picture of the node output from
 *   theme_user_picture().
 * - $date: Formatted creation date (use $created to reformat with
 *   format_date()).
 * - $links: Themed links like "Read more", "Add new comment", etc. output
 *   from theme_links().
 * - $name: Themed username of node author output from theme_user().
 * - $node_url: Direct url of the current node.
 * - $terms: the themed list of taxonomy term links output from theme_links().
 * - $submitted: themed submission information output from
 *   theme_node_submitted().
 *
 * Other variables:
 * - $node: Full node object. Contains data that may not be safe.
 * - $type: Node type, i.e. story, page, blog, etc.
 * - $comment_count: Number of comments attached to the node.
 * - $uid: User ID of the node author.
 * - $created: Time the node was published formatted in Unix timestamp.
 * - $zebra: Outputs either "even" or "odd". Useful for zebra striping in
 *   teaser listings.
 * - $id: Position of the node. Increments each time it's output.
 *
 * Node status variables:
 * - $teaser: Flag for the teaser state.
 * - $page: Flag for the full page state.
 * - $promote: Flag for front page promotion state.
 * - $sticky: Flags for sticky post setting.
 * - $status: Flag for published status.
 * - $comment: State of comment settings for the node.
 * - $readmore: Flags true if the teaser content of the node cannot hold the
 *   main body content.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 *
 * @see template_preprocess()
 * @see template_preprocess_node()
 */
?>

<?php /* _____________ TEASER ______________ */ ?>

<?php if ($teaser): ?>
	
	<div class="node <?php print $node_classes; ?>" id="node-<?php print $node->nid; ?>">
		<div class="node-inner">
	
			<h2><a href="<?php print $node_url ?>" title="<?php print $title ?>"><?php print $title; ?></a></h2>
  		
			<?php if ($submitted): ?>
			  <div class="submitted"><?php print $submitted; ?></div>
			<?php endif; ?>
			
			<div class="content">
  		  <?php print $node->teaser; ?>
  		</div>
  		
  		<?php print $links; ?>

		</div> <!-- end node-inner -->
	</div> <!-- end node-->

	
<?php else: ?>

<?php /* _____________ FULL NODE ______________ */ ?>

	<div class="node <?php print $node_classes; ?>" id="node-<?php print $node->nid; ?>">
		<div class="node-inner">
	
			<?php print $picture; ?>
	
	  	<div class="meta">
	  		<?php if ($submitted): ?>
	  		  <span class="submitted"><?php print $submitted; ?></span>
	  		<?php endif; ?>
	  		
	  		<?php if ($terms): ?>
	  		  <div class="terms terms-inline"><?php print $terms; ?></div>
	  		<?php endif;?>
	  	</div>
	  	
	  	<div class="content">
	  	  <?php print $content; ?>
	  	</div>
	  	
	  	<?php print $links; ?>
	    
		</div> <!-- end node-inner -->
	</div> <!-- end node-->

<?php endif; ?>

==> basic-6.x-1.2.tar.gz: basic/node.tpl.php <==
<?php
// $Id: node.tpl.php,v 1.1.4.4 2008/07/08 17:20:33 stevek Exp $

/**
 * @file node.tpl.php
 *
 * Theme implementation to display a node.
 *
 * Available variables:
 * - $title: the (sanitized) title of the node.
 * - $content: Node body or teaser depending on $teaser flag.
 * - $picture: The authors picture of the node output from
 *   theme_user_picture().
 * - $date: Formatted creation date (use $created to reformat with
 *   format_date()).
 * - $links: Themed links like "Read more", "Add new comment", etc. output
 *   from theme_links().
 * - $name: Themed username of node author output from theme_user().
 * - $node_url: Direct url of the current node.
 * - $terms: the themed list of taxonomy term links output from theme_links().
 * - $submitted: themed submission information output from
 *   theme_node_submitted().
 *
 * Other variables:
 * - $node: Full node object. Contains data that may not be safe.
 * - $type: Node type, i.e. story, page, blog, etc.
 * - $comment_count: Number of comments attached to the node.
 * - $uid: User ID of the node author.
 * - $created: Time the node was published formatted in Unix timestamp.
 * - $zebra: Outputs either "even" or "odd". Useful for zebra striping in
 *   teaser listings.
 * - $id: Position of the node. Increments each time it's output.
 *
 * Node status variables:
 * - $teaser: Flag for the teaser state.
 * - $page: Flag for the full page state.
 * - $promote: Flag for front page promotion state.
 * - $sticky: Flags for sticky post setting.
 * - $status: Flag for published status.
 * - $comment: State of comment settings for the node.
 * - $readmore: Flags true if the teaser content of the node cannot hold the
 *   main body content.
 * - $is_front: Flags true when presented in the front page.
 * - $logged_in: Flags true when the current user is a logged-in member.
 * - $is_admin: Flags true when the current user is an administrator.
 *
 * @see template_preprocess()
 * @see template_preprocess_node()
 */
?>

<?php /* _____________ TEASER ______________ */ ?>

<?php if ($teaser): ?>
	
	<div class="node <?php echo $node_classes; ?>" id="node-<?php echo $node->nid; ?>">
		<div class="node-inner">
	
			<h2><a href="<?php echo $node_url ?>" title="<?php echo $title ?>"><?php echo $title; ?></a></h2>
  		
			<?php if ($submitted): ?>
			  <div class="submitted"><?php echo $submitted; ?></div>
			<?php endif; ?>
			
			<div class="content">
  		  <?php echo $node->teaser; ?>
  		</div>
  		
  		<?php echo $links; ?>

		</div> <!-- end node-inner -->
	</div> <!-- end node-->

	
<?php else: ?>

<?php /* _____________ FULL NODE ______________ */ ?>

	<div class="node <?php echo $node_classes; ?>" id="node-<?php echo $node->nid; ?>">
		<div class="node-inner">
	
			<?php echo $picture; ?>
	
	  	<div class="meta">
	  		<?php if ($submitted): ?>
	  		  <span class="submitted"><?php echo $submitted; ?></span>
	  		<?php endif; ?>
	  		
	  		<?php if ($terms): ?>
	  		  <div class="terms terms-inline"><?php echo $terms; ?></div>
	  		<?php endif;?>
	  	</div>
	  	
	  	<div class="content">
	  	  <?php echo $content; ?>
	  	</div>
	  	
	  	<?php echo $links; ?>
	    
		</div> <!-- end node-inner -->
	</div> <!-- end node-->

<?php endif; ?>
